#' Read HTML from Chrome remote interface javascript-interpreted HTML
#'
#' @param url URL to load into Chromium
#' @param format one of png or jpeg
#' @param viewport_width browser width
#' @param cri_host,cri_port host and port Chrome remote interface is running on.
#' @param user_agent User-Agent string
#' @export
full_page_screenshot <- function(url, format = c("png", "jpeg"),
                                 viewport_width = 800,
                                 cri_host = "localhost", cri_port = 9222L,
                                 user_agent = "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_2) AppleWebKit/602.3.12 (KHTML, like Gecko) Version/10.0.2 Safari/602.3.12") {

  format <- match.arg(format[1], c("png", "jpeg"))
  viewport_width <- as.integer(viewport_width)

  processx::run(
    command = Sys.which("node"),
    args = c(
      system.file("js/full-page-screenshot.js", package = "spectr"),
      url,
      cri_host,
      cri_port,
      user_agent,
      format,
      viewport_width
    ),
    echo_cmd = getOption("SPECTR_DEBUG", FALSE),
    echo = getOption("SPECTR_DEBUG", FALSE)
  ) -> res

  magick::image_read(
    jsonlite::base64_dec(res$stdout)
  )

}