#' Inspect all network traffic loaded by a URL page load
#'
#' @param url URL to load into Chromium
#' @param cri_host,cri_port host and port Chrome remote interface is running on.
#' @param user_agent User-Agent string
#' @export
inspect <- function(url, cri_host = "localhost", cri_port = 9222L,
                    user_agent = "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_2) AppleWebKit/602.3.12 (KHTML, like Gecko) Version/10.0.2 Safari/602.3.12") {

  processx::run(
    command = Sys.which("node"),
    args = c(
      system.file("js/inspect.js", package = "spectr"),
      url,
      cri_host,
      cri_port,
      user_agent
    ),
    echo_cmd = getOption("SPECTR_DEBUG", FALSE),
    echo = getOption("SPECTR_DEBUG", FALSE)
  ) -> res

  out <- strsplit(res$stdout, "[\r\n]+")
  out <- unlist(out)

  out <- jsonlite::stream_in(textConnection(out[out != ""]), verbose = FALSE)

  if ("request" %in% names(out)) {
    class(out$request) <- c("tbl_df", "tbl", "data.frame")
    if ("headers" %in% names(out$request)) {
      class(out$request$headers) <- c("tbl_df", "tbl", "data.frame")
    }
  }

  if ("initiator" %in% names(out)) {
    class(out$initiator) <- c("tbl_df", "tbl", "data.frame")
    if ("stack" %in% names(out$initiator)) {
      class(out$initiator$stack) <- c("tbl_df", "tbl", "data.frame")
    }
  }

  if ("redirectResponse" %in% names(out)) {
    class(out$redirectResponse) <- c("tbl_df", "tbl", "data.frame")
    if ("headers" %in% names(out$redirectResponse)) {
      class(out$redirectResponse$headers) <- c("tbl_df", "tbl", "data.frame")
    }
    if ("requestHeaders" %in% names(out$redirectResponse)) {
      class(out$redirectResponse$requestHeaders) <- c("tbl_df", "tbl", "data.frame")
    }
    if ("timing" %in% names(out$redirectResponse)) {
      class(out$redirectResponse$timing) <- c("tbl_df", "tbl", "data.frame")
    }
    if ("securityDetails" %in% names(out$redirectResponse)) {
      class(out$redirectResponse$securityDetails) <- c("tbl_df", "tbl", "data.frame")
    }
  }

  if ("response" %in% names(out)) {
    class(out$response) <- c("tbl_df", "tbl", "data.frame")
    if ("timing" %in% names(out$response)) {
      class(out$response$timing) <- c("tbl_df", "tbl", "data.frame")
    }
    if ("securityDetails" %in% names(out$response)) {
      class(out$response$securityDetails) <- c("tbl_df", "tbl", "data.frame")
    }
  }

  class(out) <- c("tbl_df", "tbl", "data.frame")

  out

}