
[![Project Status: Active – The project has reached a stable, usable
state and is being actively
developed.](https://www.repostatus.org/badges/latest/active.svg)](https://www.repostatus.org/#active)
[![Signed
by](https://img.shields.io/badge/Keybase-Verified-brightgreen.svg)](https://keybase.io/hrbrmstr)
![Signed commit
%](https://img.shields.io/badge/Signed_Commits-100%25-lightgrey.svg)
[![Linux build
Status](https://travis-ci.org/hrbrmstr/spectr.svg?branch=master)](https://travis-ci.org/hrbrmstr/spectr)  
![Minimal R
Version](https://img.shields.io/badge/R%3E%3D-3.2.0-blue.svg)
![License](https://img.shields.io/badge/License-AGPL-blue.svg)

# spectr

Wrappers for Selected Chrome Remote Interface Utilities

## Description

Wrappers for Selected Chrome Remote Interface Utilities

## What’s Inside The Tin

The following functions are implemented:

  - `apex_or_public_suffix`: Extract apex (or public suffix if no proper
    apex) from a FQDN or URL
  - `cri_active`: Test if Chrome Remote Interface is running on the
    given host/port
  - `cri_read_html`: Read HTML from Chrome remote interface
    javascript-interpreted HTML
  - `extract_url_and_content_type`: Extract final URL & content type
    from response column
  - `full_page_screenshot`: Read HTML from Chrome remote interface
    javascript-interpreted HTML
  - `%isna%`: Infix NA tester and alt value chooser
  - `inspect`: Inspect all network traffic loaded by a URL page load

## Installation

``` r
remotes::install_git("https://git.rud.is/hrbrmstr/spectr.git")
# or
remotes::install_git("https://git.sr.ht/~hrbrmstr/spectr")
# or
remotes::install_gitlab("hrbrmstr/spectr")
# or
remotes::install_bitbucket("hrbrmstr/spectr")
```

NOTE: To use the ‘remotes’ install options you will need to have the
[{remotes} package](https://github.com/r-lib/remotes) installed.

## Usage

``` r
library(spectr)

# current version
packageVersion("spectr")
## [1] '0.1.0'
```

### Test if Chrome Remote Interface is running

``` r
cri_active()
## [1] TRUE
```

### Look at all the requests made by visiting RStudio

``` r
library(dplyr)
library(tidyr)

site <- inspect("http://rstudio.org")

group_by(site, requestId) %>%
  summarise(orig_url = request$url[1], r = extract_url_and_content_type(response)) %>%
  unnest() %>%
  mutate(apex = apex_or_public_suffix(url)) %>% 
  knitr::kable("markdown")
```

| requestId                        | orig\_url                                                                                                                                                                                       | url                                                                                                                                                                                             | mimeType                 | apex                 |
| :------------------------------- | :---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | :---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | :----------------------- | :------------------- |
| 1000002156.10                    | [https://fonts.googleapis.com/css?family=Source+Sans+Pro:300|Source+Sans+Pro:200\&subset=latin](https://fonts.googleapis.com/css?family=Source+Sans+Pro:300%7CSource+Sans+Pro:200&subset=latin) | [https://fonts.googleapis.com/css?family=Source+Sans+Pro:300|Source+Sans+Pro:200\&subset=latin](https://fonts.googleapis.com/css?family=Source+Sans+Pro:300%7CSource+Sans+Pro:200&subset=latin) | text/css                 | fonts.googleapis.com |
| 1000002156.100                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-toggles.js?ver=1>                                                      | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-toggles.js?ver=1>                                                      | application/javascript   | netdna-ssl.com       |
| 1000002156.101                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/library/jquery.countdown.js?ver=1.0>                                                  | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/library/jquery.countdown.js?ver=1.0>                                                  | application/javascript   | netdna-ssl.com       |
| 1000002156.102                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-countdown.js?ver=1>                                                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-countdown.js?ver=1>                                                    | application/javascript   | netdna-ssl.com       |
| 1000002156.103                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-events.js?ver=1>                                                       | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-events.js?ver=1>                                                       | application/javascript   | netdna-ssl.com       |
| 1000002156.104                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-title.js?ver=1>                                                        | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-title.js?ver=1>                                                        | application/javascript   | netdna-ssl.com       |
| 1000002156.105                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.fade.js?ver=1>                                                      | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.fade.js?ver=1>                                                      | application/javascript   | netdna-ssl.com       |
| 1000002156.106                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.requestAnimationFrame.js?ver=1>                                     | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.requestAnimationFrame.js?ver=1>                                     | application/javascript   | netdna-ssl.com       |
| 1000002156.107                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/fusion-parallax.js?ver=1>                                                  | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/fusion-parallax.js?ver=1>                                                  | application/javascript   | netdna-ssl.com       |
| 1000002156.108                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/fusion-video-bg.js?ver=1>                                                  | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/fusion-video-bg.js?ver=1>                                                  | application/javascript   | netdna-ssl.com       |
| 1000002156.109                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-container.js?ver=1>                                                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-container.js?ver=1>                                                    | application/javascript   | netdna-ssl.com       |
| 1000002156.11                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/css/style.min.css?ver=5.9>                                                                             | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/css/style.min.css?ver=5.9>                                                                             | text/css                 | netdna-ssl.com       |
| 1000002156.110                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.cycle.js?ver=3.0.3>                                                 | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.cycle.js?ver=3.0.3>                                                 | application/javascript   | netdna-ssl.com       |
| 1000002156.111                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-testimonials.js?ver=1>                                                 | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-testimonials.js?ver=1>                                                 | application/javascript   | netdna-ssl.com       |
| 1000002156.112                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.fusion_maps.js?ver=2.2.2>                                           | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.fusion_maps.js?ver=2.2.2>                                           | application/javascript   | netdna-ssl.com       |
| 1000002156.113                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-google-map.js?ver=1>                                                | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-google-map.js?ver=1>                                                | application/javascript   | netdna-ssl.com       |
| 1000002156.114                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/bootstrap.modal.js?ver=3.1.1>                                              | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/bootstrap.modal.js?ver=3.1.1>                                              | application/javascript   | netdna-ssl.com       |
| 1000002156.115                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-modal.js?ver=1>                                                        | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-modal.js?ver=1>                                                        | application/javascript   | netdna-ssl.com       |
| 1000002156.116                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-progress.js?ver=1>                                                     | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-progress.js?ver=1>                                                     | application/javascript   | netdna-ssl.com       |
| 1000002156.117                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/vimeoPlayer.js?ver=2.2.1>                                                  | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/vimeoPlayer.js?ver=2.2.1>                                                  | application/javascript   | netdna-ssl.com       |
| 1000002156.118                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-video.js?ver=1>                                                        | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-video.js?ver=1>                                                        | application/javascript   | netdna-ssl.com       |
| 1000002156.119                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.hoverintent.js?ver=1>                                               | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.hoverintent.js?ver=1>                                               | application/javascript   | netdna-ssl.com       |
| 1000002156.12                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/ekYDNiJzrjUc/bZpBkBxfMOaO.css?ver=2.2.3>                                                                           | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/ekYDNiJzrjUc/bZpBkBxfMOaO.css?ver=2.2.3>                                                                           | text/css                 | netdna-ssl.com       |
| 1000002156.120                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-vertical-menu-widget.js?ver=1>                                                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-vertical-menu-widget.js?ver=1>                                                    | application/javascript   | netdna-ssl.com       |
| 1000002156.121                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/lazysizes.js?ver=4.1.5>                                                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/lazysizes.js?ver=4.1.5>                                                    | application/javascript   | netdna-ssl.com       |
| 1000002156.122                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/bootstrap.tooltip.js?ver=3.3.5>                                            | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/bootstrap.tooltip.js?ver=3.3.5>                                            | application/javascript   | netdna-ssl.com       |
| 1000002156.123                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/bootstrap.popover.js?ver=3.3.5>                                            | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/bootstrap.popover.js?ver=3.3.5>                                            | application/javascript   | netdna-ssl.com       |
| 1000002156.124                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.carouFredSel.js?ver=6.2.1>                                          | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.carouFredSel.js?ver=6.2.1>                                          | application/javascript   | netdna-ssl.com       |
| 1000002156.125                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.easing.js?ver=1.3>                                                  | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.easing.js?ver=1.3>                                                  | application/javascript   | netdna-ssl.com       |
| 1000002156.126                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.flexslider.js?ver=2.2.2>                                            | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.flexslider.js?ver=2.2.2>                                            | application/javascript   | netdna-ssl.com       |
| 1000002156.127                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.hoverflow.js?ver=1>                                                 | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.hoverflow.js?ver=1>                                                 | application/javascript   | netdna-ssl.com       |
| 1000002156.128                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.placeholder.js?ver=2.0.7>                                           | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.placeholder.js?ver=2.0.7>                                           | application/javascript   | netdna-ssl.com       |
| 1000002156.129                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.touchSwipe.js?ver=1.6.6>                                            | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.touchSwipe.js?ver=1.6.6>                                            | application/javascript   | netdna-ssl.com       |
| 1000002156.13                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-includes/js/jquery/jquery.js?ver=1.12.4>                                                                                           | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-includes/js/jquery/jquery.js?ver=1.12.4>                                                                                           | application/javascript   | netdna-ssl.com       |
| 1000002156.130                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-alert.js?ver=1>                                                     | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-alert.js?ver=1>                                                     | application/javascript   | netdna-ssl.com       |
| 1000002156.131                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-carousel.js?ver=1>                                                  | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-carousel.js?ver=1>                                                  | application/javascript   | netdna-ssl.com       |
| 1000002156.132                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-flexslider.js?ver=1>                                                | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-flexslider.js?ver=1>                                                | application/javascript   | netdna-ssl.com       |
| 1000002156.133                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-popover.js?ver=1>                                                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-popover.js?ver=1>                                                   | application/javascript   | netdna-ssl.com       |
| 1000002156.134                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-tooltip.js?ver=1>                                                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-tooltip.js?ver=1>                                                   | application/javascript   | netdna-ssl.com       |
| 1000002156.135                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-sharing-box.js?ver=1>                                               | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-sharing-box.js?ver=1>                                               | application/javascript   | netdna-ssl.com       |
| 1000002156.136                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-blog.js?ver=1>                                                      | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-blog.js?ver=1>                                                      | application/javascript   | netdna-ssl.com       |
| 1000002156.137                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-button.js?ver=1>                                                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-button.js?ver=1>                                                    | application/javascript   | netdna-ssl.com       |
| 1000002156.138                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-general-global.js?ver=1>                                            | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-general-global.js?ver=1>                                            | application/javascript   | netdna-ssl.com       |
| 1000002156.139                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-header.js?ver=5.9>                                                                | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-header.js?ver=5.9>                                                                | application/javascript   | netdna-ssl.com       |
| 1000002156.14                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-includes/js/jquery/jquery-migrate.min.js?ver=1.4.1>                                                                                | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-includes/js/jquery/jquery-migrate.min.js?ver=1.4.1>                                                                                | application/javascript   | netdna-ssl.com       |
| 1000002156.140                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-menu.js?ver=5.9>                                                                  | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-menu.js?ver=5.9>                                                                  | application/javascript   | netdna-ssl.com       |
| 1000002156.141                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-scroll-to-anchor.js?ver=1>                                          | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-scroll-to-anchor.js?ver=1>                                          | application/javascript   | netdna-ssl.com       |
| 1000002156.142                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-responsive-typography.js?ver=1>                                     | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-responsive-typography.js?ver=1>                                     | application/javascript   | netdna-ssl.com       |
| 1000002156.143                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/library/bootstrap.scrollspy.js?ver=3.3.2>                                                       | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/library/bootstrap.scrollspy.js?ver=3.3.2>                                                       | application/javascript   | netdna-ssl.com       |
| 1000002156.144                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-comments.js?ver=5.9>                                                              | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-comments.js?ver=5.9>                                                              | application/javascript   | netdna-ssl.com       |
| 1000002156.145                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-general-footer.js?ver=5.9>                                                        | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-general-footer.js?ver=5.9>                                                        | application/javascript   | netdna-ssl.com       |
| 1000002156.146                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-quantity.js?ver=5.9>                                                              | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-quantity.js?ver=5.9>                                                              | application/javascript   | netdna-ssl.com       |
| 1000002156.147                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-scrollspy.js?ver=5.9>                                                             | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-scrollspy.js?ver=5.9>                                                             | application/javascript   | netdna-ssl.com       |
| 1000002156.148                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-select.js?ver=5.9>                                                                | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-select.js?ver=5.9>                                                                | application/javascript   | netdna-ssl.com       |
| 1000002156.149                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-sidebars.js?ver=5.9>                                                              | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-sidebars.js?ver=5.9>                                                              | application/javascript   | netdna-ssl.com       |
| 1000002156.15                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/rotatingtweets/js/jquery.cycle.all.min.js?ver=5.1.1>                                                               | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/rotatingtweets/js/jquery.cycle.all.min.js?ver=5.1.1>                                                               | application/javascript   | netdna-ssl.com       |
| 1000002156.150                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/library/jquery.sticky-kit.js?ver=5.9>                                                           | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/library/jquery.sticky-kit.js?ver=5.9>                                                           | application/javascript   | netdna-ssl.com       |
| 1000002156.151                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-tabs-widget.js?ver=5.9>                                                           | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-tabs-widget.js?ver=5.9>                                                           | application/javascript   | netdna-ssl.com       |
| 1000002156.152                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/library/jquery.toTop.js?ver=1.2>                                                                | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/library/jquery.toTop.js?ver=1.2>                                                                | application/javascript   | netdna-ssl.com       |
| 1000002156.153                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-to-top.js?ver=5.9>                                                                | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-to-top.js?ver=5.9>                                                                | application/javascript   | netdna-ssl.com       |
| 1000002156.154                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-drop-down.js?ver=5.9>                                                             | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-drop-down.js?ver=5.9>                                                             | application/javascript   | netdna-ssl.com       |
| 1000002156.155                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-rev-styles.js?ver=5.9>                                                            | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-rev-styles.js?ver=5.9>                                                            | application/javascript   | netdna-ssl.com       |
| 1000002156.156                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/library/jquery.elasticslider.js?ver=5.9>                                                        | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/library/jquery.elasticslider.js?ver=5.9>                                                        | application/javascript   | netdna-ssl.com       |
| 1000002156.157                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-elastic-slider.js?ver=5.9>                                                        | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/min/js/general/avada-elastic-slider.js?ver=5.9>                                                        | application/javascript   | netdna-ssl.com       |
| 1000002156.158                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-core/js/min/avada-fusion-slider.js?ver=1>                                                                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-core/js/min/avada-fusion-slider.js?ver=1>                                                                   | application/javascript   | netdna-ssl.com       |
| 1000002156.159                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/ekYDNiJzrjUc/wlWnwGTPbZAG.js?ver=2.2.3>                                                                            | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/ekYDNiJzrjUc/wlWnwGTPbZAG.js?ver=2.2.3>                                                                            | application/javascript   | netdna-ssl.com       |
| 1000002156.16                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/rotatingtweets/js/rotating_tweet.js?ver=1.9.8>                                                                     | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/rotatingtweets/js/rotating_tweet.js?ver=1.9.8>                                                                     | application/javascript   | netdna-ssl.com       |
| 1000002156.160                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-includes/js/wp-embed.min.js?ver=5.1.1>                                                                                             | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-includes/js/wp-embed.min.js?ver=5.1.1>                                                                                             | application/javascript   | netdna-ssl.com       |
| 1000002156.17                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/wp-google-analytics-events/js/ga-scroll-events.js?ver=2.5.3>                                                       | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/wp-google-analytics-events/js/ga-scroll-events.js?ver=2.5.3>                                                       | application/javascript   | netdna-ssl.com       |
| 1000002156.18                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/LayerSlider/static/layerslider/js/greensock.js?ver=1.19.0>                                                         | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/LayerSlider/static/layerslider/js/greensock.js?ver=1.19.0>                                                         | application/javascript   | netdna-ssl.com       |
| 1000002156.19                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/LayerSlider/static/layerslider/js/layerslider.kreaturamedia.jquery.js?ver=6.8.2>                                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/LayerSlider/static/layerslider/js/layerslider.kreaturamedia.jquery.js?ver=6.8.2>                                   | application/javascript   | netdna-ssl.com       |
| 1000002156.2                     | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/LayerSlider/static/layerslider/css/layerslider.css?ver=6.8.2>                                                      | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/LayerSlider/static/layerslider/css/layerslider.css?ver=6.8.2>                                                      | text/css                 | netdna-ssl.com       |
| 1000002156.20                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/LayerSlider/static/layerslider/js/layerslider.transitions.js?ver=6.8.2>                                            | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/LayerSlider/static/layerslider/js/layerslider.transitions.js?ver=6.8.2>                                            | application/javascript   | netdna-ssl.com       |
| 1000002156.21                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/swiftype-search/assets/install_swiftype.min.js?ver=5.1.1>                                                          | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/swiftype-search/assets/install_swiftype.min.js?ver=5.1.1>                                                          | application/javascript   | netdna-ssl.com       |
| 1000002156.22                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/revslider/public/assets/js/jquery.themepunch.tools.min.js?ver=5.4.8.3>                                             | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/revslider/public/assets/js/jquery.themepunch.tools.min.js?ver=5.4.8.3>                                             | application/javascript   | netdna-ssl.com       |
| 1000002156.23                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/revslider/public/assets/js/jquery.themepunch.revolution.min.js?ver=5.4.8.3>                                        | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/revslider/public/assets/js/jquery.themepunch.revolution.min.js?ver=5.4.8.3>                                        | application/javascript   | netdna-ssl.com       |
| 1000002156.24                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/revslider-whiteboard-addon/public/assets/js/revolution.addon.whiteboard.min.js?ver=1.0.6>                          | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/revslider-whiteboard-addon/public/assets/js/revolution.addon.whiteboard.min.js?ver=1.0.6>                          | application/javascript   | netdna-ssl.com       |
| 1000002156.25                    | <https://www.rstudio.com/wp-includes/js/wp-emoji-release.min.js?ver=5.1.1>                                                                                                                      | <https://www.rstudio.com/wp-includes/js/wp-emoji-release.min.js?ver=5.1.1>                                                                                                                      | application/javascript   | rstudio.com          |
| 1000002156.259                   | <https://cdn.segment.com/analytics.js/v1/DqzuXuDtDnYU8hFgwrVvXcplzLpXEAh2/analytics.min.js>                                                                                                     | NA                                                                                                                                                                                              | NA                       | na                   |
| 1000002156.260                   | <https://js.driftt.com/include/1566177000000/w9tizmx5avtp.js>                                                                                                                                   | <https://js.driftt.com/include/1566177000000/w9tizmx5avtp.js>                                                                                                                                   | application/javascript   | driftt.com           |
| 1000002156.261                   | <https://www.google-analytics.com/analytics.js>                                                                                                                                                 | NA                                                                                                                                                                                              | NA                       | na                   |
| 1000002156.263                   | <https://x.clearbitjs.com/v1/pk_60c5aa2221e3c03eca10fb6876aa6df7/clearbit.js>                                                                                                                   | <https://x.clearbitjs.com/v1/pk_60c5aa2221e3c03eca10fb6876aa6df7/clearbit.js>                                                                                                                   | application/javascript   | clearbitjs.com       |
| 1000002156.274                   | <https://fonts.gstatic.com/s/sourcesanspro/v13/6xKydSBYKcSV-LCoeQqfX1RYOo3i94_wlxdr.ttf>                                                                                                        | <https://fonts.gstatic.com/s/sourcesanspro/v13/6xKydSBYKcSV-LCoeQqfX1RYOo3i94_wlxdr.ttf>                                                                                                        | font/ttf                 | gstatic.com          |
| 1000002156.275                   | <https://fonts.gstatic.com/s/sourcesanspro/v13/6xKydSBYKcSV-LCoeQqfX1RYOo3ik4zwlxdr.ttf>                                                                                                        | <https://fonts.gstatic.com/s/sourcesanspro/v13/6xKydSBYKcSV-LCoeQqfX1RYOo3ik4zwlxdr.ttf>                                                                                                        | font/ttf                 | gstatic.com          |
| 1000002156.277                   | <https://fonts.gstatic.com/s/sourcesanspro/v13/6xKydSBYKcSV-LCoeQqfX1RYOo3ig4vwlxdr.ttf>                                                                                                        | <https://fonts.gstatic.com/s/sourcesanspro/v13/6xKydSBYKcSV-LCoeQqfX1RYOo3ig4vwlxdr.ttf>                                                                                                        | font/ttf                 | gstatic.com          |
| 1000002156.278                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/fonts/icomoon/icomoon.woff>                                                               | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/fonts/icomoon/icomoon.woff>                                                               | application/font-woff    | netdna-ssl.com       |
| 1000002156.295                   | <https://fonts.gstatic.com/s/sourcesanspro/v13/6xK3dSBYKcSV-LCoeQqfX1RYOo3qOK7lujVj9w.woff2>                                                                                                    | <https://fonts.gstatic.com/s/sourcesanspro/v13/6xK3dSBYKcSV-LCoeQqfX1RYOo3qOK7lujVj9w.woff2>                                                                                                    | font/woff2               | gstatic.com          |
| 1000002156.3                     | <https://fonts.googleapis.com/css?family=Lato:100,300,regular,700,900%7COpen+Sans:300%7CIndie+Flower:regular%7COswald:300,regular,700&subset=latin%2Clatin-ext>                                 | <https://fonts.googleapis.com/css?family=Lato:100,300,regular,700,900%7COpen+Sans:300%7CIndie+Flower:regular%7COswald:300,regular,700&subset=latin%2Clatin-ext>                                 | text/css                 | fonts.googleapis.com |
| 1000002156.302                   | <https://fonts.gstatic.com/s/sourcesanspro/v13/6xKydSBYKcSV-LCoeQqfX1RYOo3i54rwlxdu3cOWxw.woff2>                                                                                                | <https://fonts.gstatic.com/s/sourcesanspro/v13/6xKydSBYKcSV-LCoeQqfX1RYOo3i54rwlxdu3cOWxw.woff2>                                                                                                | font/woff2               | gstatic.com          |
| 1000002156.309                   | <https://fonts.gstatic.com/s/sourcesanspro/v13/6xKydSBYKcSV-LCoeQqfX1RYOo3iu4nwlxdu3cOWxw.woff2>                                                                                                | <https://fonts.gstatic.com/s/sourcesanspro/v13/6xKydSBYKcSV-LCoeQqfX1RYOo3iu4nwlxdu3cOWxw.woff2>                                                                                                | font/woff2               | gstatic.com          |
| 1000002156.38                    | <https://ga.clearbit.com/v1/ga.js?authorization=pk_60c5aa2221e3c03eca10fb6876aa6df7>                                                                                                            | NA                                                                                                                                                                                              | NA                       | na                   |
| 1000002156.39                    | <https://www.rstudio.com/wp-content/uploads/2019/03/RStudio-Logo-Blue-Gray-125.png>                                                                                                             | <https://www.rstudio.com/wp-content/uploads/2019/03/RStudio-Logo-Blue-Gray-125.png>                                                                                                             | image/png                | rstudio.com          |
| 1000002156.4                     | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/swiftype-search/assets/autocomplete.css?ver=5.1.1>                                                                 | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/swiftype-search/assets/autocomplete.css?ver=5.1.1>                                                                 | text/css                 | netdna-ssl.com       |
| 1000002156.40                    | <https://www.rstudio.com/wp-content/uploads/2016/09/RStudio-Logo-Blue-Gray-125.png>                                                                                                             | <https://www.rstudio.com/wp-content/uploads/2016/09/RStudio-Logo-Blue-Gray-125.png>                                                                                                             | image/png                | rstudio.com          |
| 1000002156.402                   | <http://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/07/2020-sf-hero.jpg>                                                                                           | <http://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/07/2020-sf-hero.jpg>                                                                                           | image/jpeg               | netdna-ssl.com       |
| 1000002156.403                   | <data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7>                                                                                                                | <data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///yH5BAEAAAAALAAAAAABAAEAAAIBRAA7>                                                                                                                | image/gif                | na                   |
| 1000002156.41                    | <https://fonts.googleapis.com/css?family=Source+Sans+Pro:900%2C600%2C400>                                                                                                                       | <https://fonts.googleapis.com/css?family=Source+Sans+Pro:900%2C600%2C400>                                                                                                                       | text/css                 | fonts.googleapis.com |
| 1000002156.42                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/05/blue-hex-hero-darker.png>                                                                                  | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/05/blue-hex-hero-darker.png>                                                                                  | image/png                | netdna-ssl.com       |
| 1000002156.43                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/05/RSP-bg.png>                                                                                                | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/05/RSP-bg.png>                                                                                                | image/png                | netdna-ssl.com       |
| 1000002156.44                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/05/RSP-Screenshot-web.png>                                                                                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/05/RSP-Screenshot-web.png>                                                                                    | image/png                | netdna-ssl.com       |
| 1000002156.45                    | <http://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/01/favIcon114.png>                                                                                             | <http://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/01/favIcon114.png>                                                                                             | image/png                | netdna-ssl.com       |
| 1000002156.46                    | <http://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/06/connect-icon.png>                                                                                           | <http://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/06/connect-icon.png>                                                                                           | image/png                | netdna-ssl.com       |
| 1000002156.47                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/06/icon-rspm-1.png>                                                                                           | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/06/icon-rspm-1.png>                                                                                           | image/png                | netdna-ssl.com       |
| 1000002156.48                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/07/2020-logo-800x160.png>                                                                                     | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/07/2020-logo-800x160.png>                                                                                     | image/png                | netdna-ssl.com       |
| 1000002156.49                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/08/so-logo-800x191.png>                                                                                       | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/08/so-logo-800x191.png>                                                                                       | image/png                | netdna-ssl.com       |
| 1000002156.5                     | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/font-awesome-4-menus/css/font-awesome.min.css?ver=4.7.0>                                                           | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/font-awesome-4-menus/css/font-awesome.min.css?ver=4.7.0>                                                           | text/css                 | netdna-ssl.com       |
| 1000002156.51                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/06/professional-fans-800x332.jpg>                                                                             | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2019/06/professional-fans-800x332.jpg>                                                                             | image/jpeg               | netdna-ssl.com       |
| 1000002156.52                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2014/05/logo-white@2x.png>                                                                                         | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2014/05/logo-white@2x.png>                                                                                         | image/png                | netdna-ssl.com       |
| 1000002156.53                    | <http://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2014/03/GitHub-Mark-Light-32px.png>                                                                                 | <http://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/uploads/2014/03/GitHub-Mark-Light-32px.png>                                                                                 | image/png                | netdna-ssl.com       |
| 1000002156.54                    | <https://fonts.googleapis.com/css?family=Roboto+Condensed%3A300%2C300i%2C400%2C400i%2C700%2C700i%7CRoboto%3A300%2C300i%2C400%2C400i%2C500%2C500i%2C700%2C700i&ver=5.1.1>                        | <https://fonts.googleapis.com/css?family=Roboto+Condensed%3A300%2C300i%2C400%2C400i%2C700%2C700i%7CRoboto%3A300%2C300i%2C400%2C400i%2C500%2C500i%2C700%2C700i&ver=5.1.1>                        | text/css                 | fonts.googleapis.com |
| 1000002156.546                   | <https://x.clearbit.com/v1/p>                                                                                                                                                                   | <https://x.clearbit.com/v1/p>                                                                                                                                                                   | application/json         | clearbit.com         |
| 1000002156.55                    | <https://fonts.googleapis.com/css?family=Open+Sans%3A400%2C400i%2C700%2C700i&ver=5.1.1>                                                                                                         | <https://fonts.googleapis.com/css?family=Open+Sans%3A400%2C400i%2C700%2C700i&ver=5.1.1>                                                                                                         | text/css                 | fonts.googleapis.com |
| 1000002156.56                    | <https://fonts.googleapis.com/css?family=Source+Code+Pro&ver=5.1.1>                                                                                                                             | <https://fonts.googleapis.com/css?family=Source+Code+Pro&ver=5.1.1>                                                                                                                             | text/css                 | fonts.googleapis.com |
| 1000002156.57                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-includes/css/dashicons.min.css?ver=5.1.1>                                                                                          | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-includes/css/dashicons.min.css?ver=5.1.1>                                                                                          | text/css                 | netdna-ssl.com       |
| 1000002156.58                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/wordpress-popup/assets/css/front.min.css?ver=3.0.7>                                                                | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/wordpress-popup/assets/css/front.min.css?ver=3.0.7>                                                                | text/css                 | netdna-ssl.com       |
| 1000002156.59                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-includes/js/underscore.min.js?ver=1.8.3>                                                                                           | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-includes/js/underscore.min.js?ver=1.8.3>                                                                                           | application/javascript   | netdna-ssl.com       |
| 1000002156.6                     | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/revslider/public/assets/css/settings.css?ver=5.4.8.3>                                                              | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/revslider/public/assets/css/settings.css?ver=5.4.8.3>                                                              | text/css                 | netdna-ssl.com       |
| 1000002156.60                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/wordpress-popup/assets/js/front.min.js?ver=1.1>                                                                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/wordpress-popup/assets/js/front.min.js?ver=1.1>                                                                    | application/javascript   | netdna-ssl.com       |
| 1000002156.61                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/wp-discourse/js/load-comments.js?ver=1.8.7>                                                                        | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/wp-discourse/js/load-comments.js?ver=1.8.7>                                                                        | application/javascript   | netdna-ssl.com       |
| 1000002156.62                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-includes/js/comment-reply.min.js?ver=5.1.1>                                                                                        | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-includes/js/comment-reply.min.js?ver=5.1.1>                                                                                        | application/javascript   | netdna-ssl.com       |
| 1000002156.63                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/isotope.js?ver=3.0.4>                                                      | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/isotope.js?ver=3.0.4>                                                      | application/javascript   | netdna-ssl.com       |
| 1000002156.64                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.infinitescroll.js?ver=2.1>                                          | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.infinitescroll.js?ver=2.1>                                          | application/javascript   | netdna-ssl.com       |
| 1000002156.645                   | <https://s.swiftypecdn.com/install/v2/st.js>                                                                                                                                                    | <https://s.swiftypecdn.com/install/v2/st.js>                                                                                                                                                    | text/javascript          | swiftypecdn.com      |
| 1000002156.646                   | <https://www.rstudio.com/wp-json/wp-discourse/v1/discourse-comments?post_id=undefined>                                                                                                          | <https://www.rstudio.com/wp-json/wp-discourse/v1/discourse-comments?post_id=undefined>                                                                                                          | application/json         | rstudio.com          |
| 1000002156.647                   | <https://www.rstudio.com/wp-content/uploads/2019/07/2020-sf-hero.jpg>                                                                                                                           | <https://www.rstudio.com/wp-content/uploads/2019/07/2020-sf-hero.jpg>                                                                                                                           | image/jpeg               | rstudio.com          |
| 1000002156.648                   | <https://s.swiftypecdn.com/cc.js>                                                                                                                                                               | <https://s.swiftypecdn.com/cc.js>                                                                                                                                                               | text/javascript          | swiftypecdn.com      |
| 1000002156.649                   | <https://www.rstudio.com/wp-content/plugins/revslider/public/assets/js/extensions/revolution.extension.slideanims.min.js?version=5.4.8>                                                         | <https://www.rstudio.com/wp-content/plugins/revslider/public/assets/js/extensions/revolution.extension.slideanims.min.js?version=5.4.8>                                                         | application/javascript   | rstudio.com          |
| 1000002156.65                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-core/js/min/avada-faqs.js?ver=1>                                                                            | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-core/js/min/avada-faqs.js?ver=1>                                                                            | application/javascript   | netdna-ssl.com       |
| 1000002156.650                   | <https://www.rstudio.com/wp-content/plugins/revslider/public/assets/js/extensions/revolution.extension.actions.min.js?version=5.4.8>                                                            | <https://www.rstudio.com/wp-content/plugins/revslider/public/assets/js/extensions/revolution.extension.actions.min.js?version=5.4.8>                                                            | application/javascript   | rstudio.com          |
| 1000002156.651                   | <https://www.rstudio.com/wp-content/plugins/revslider/public/assets/js/extensions/revolution.extension.layeranimation.min.js?version=5.4.8>                                                     | <https://www.rstudio.com/wp-content/plugins/revslider/public/assets/js/extensions/revolution.extension.layeranimation.min.js?version=5.4.8>                                                     | application/javascript   | rstudio.com          |
| 1000002156.652                   | <https://www.rstudio.com/wp-content/plugins/revslider/public/assets/js/extensions/revolution.extension.navigation.min.js?version=5.4.8>                                                         | <https://www.rstudio.com/wp-content/plugins/revslider/public/assets/js/extensions/revolution.extension.navigation.min.js?version=5.4.8>                                                         | application/javascript   | rstudio.com          |
| 1000002156.653                   | <https://www.rstudio.com/wp-content/plugins/revslider/public/assets/js/extensions/revolution.extension.parallax.min.js?version=5.4.8>                                                           | <https://www.rstudio.com/wp-content/plugins/revslider/public/assets/js/extensions/revolution.extension.parallax.min.js?version=5.4.8>                                                           | application/javascript   | rstudio.com          |
| 1000002156.657                   | <https://s.swiftypecdn.com/install/v2/config/t2KJMr9_77QjXsTW-NMw.json>                                                                                                                         | NA                                                                                                                                                                                              | NA                       | na                   |
| 1000002156.658                   | <https://cc.swiftype.com/cc?url=https%3A%2F%2Fwww.rstudio.com%2F&engine_key=>                                                                                                                   | <https://cc.swiftype.com/cc?url=https%3A%2F%2Fwww.rstudio.com%2F&engine_key=>                                                                                                                   | application/octet-stream | swiftype.com         |
| 1000002156.659                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/images/shadow-top.png>                                                                                 | NA                                                                                                                                                                                              | NA                       | na                   |
| 1000002156.66                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/modernizr.js?ver=3.3.1>                                                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/modernizr.js?ver=3.3.1>                                                    | application/javascript   | netdna-ssl.com       |
| 1000002156.660                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/assets/images/shadow-bottom.png>                                                                              | NA                                                                                                                                                                                              | NA                       | na                   |
| 1000002156.661                   | <https://www.rstudio.com/wp-content/uploads/2016/09/RStudio-Logo-Blue-Gray-250.png>                                                                                                             | NA                                                                                                                                                                                              | NA                       | na                   |
| 1000002156.67                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.fitvids.js?ver=1.1>                                                 | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.fitvids.js?ver=1.1>                                                 | application/javascript   | netdna-ssl.com       |
| 1000002156.68                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/fusion-video-general.js?ver=1>                                             | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/fusion-video-general.js?ver=1>                                             | application/javascript   | netdna-ssl.com       |
| 1000002156.69                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.ilightbox.js?ver=2.2.3>                                             | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.ilightbox.js?ver=2.2.3>                                             | application/javascript   | netdna-ssl.com       |
| 1000002156.7                     | <https://fonts.googleapis.com/css?family=Open+Sans:400,800,300,700,600>                                                                                                                         | <https://fonts.googleapis.com/css?family=Open+Sans:400,800,300,700,600>                                                                                                                         | text/css                 | fonts.googleapis.com |
| 1000002156.70                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.mousewheel.js?ver=3.0.6>                                            | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.mousewheel.js?ver=3.0.6>                                            | application/javascript   | netdna-ssl.com       |
| 1000002156.71                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-lightbox.js?ver=1>                                                  | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-lightbox.js?ver=1>                                                  | application/javascript   | netdna-ssl.com       |
| 1000002156.72                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/imagesLoaded.js?ver=3.1.8>                                                 | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/imagesLoaded.js?ver=3.1.8>                                                 | application/javascript   | netdna-ssl.com       |
| 1000002156.73                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/packery.js?ver=2.0.0>                                                      | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/packery.js?ver=2.0.0>                                                      | application/javascript   | netdna-ssl.com       |
| 1000002156.74                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-core/js/min/avada-portfolio.js?ver=1>                                                                       | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-core/js/min/avada-portfolio.js?ver=1>                                                                       | application/javascript   | netdna-ssl.com       |
| 1000002156.75                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/cssua.js?ver=2.1.28>                                                       | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/cssua.js?ver=2.1.28>                                                       | application/javascript   | netdna-ssl.com       |
| 1000002156.76                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.waypoints.js?ver=2.0.3>                                             | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.waypoints.js?ver=2.0.3>                                             | application/javascript   | netdna-ssl.com       |
| 1000002156.77                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-waypoints.js?ver=1>                                                 | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-waypoints.js?ver=1>                                                 | application/javascript   | netdna-ssl.com       |
| 1000002156.78                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-animations.js?ver=1>                                                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-animations.js?ver=1>                                                   | application/javascript   | netdna-ssl.com       |
| 1000002156.79                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/library/jquery.countTo.js?ver=1>                                                      | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/library/jquery.countTo.js?ver=1>                                                      | application/javascript   | netdna-ssl.com       |
| 1000002156.8                     | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/rotatingtweets/css/style.css?ver=5.1.1>                                                                            | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/rotatingtweets/css/style.css?ver=5.1.1>                                                                            | text/css                 | netdna-ssl.com       |
| 1000002156.80                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.appear.js?ver=1>                                                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.appear.js?ver=1>                                                    | application/javascript   | netdna-ssl.com       |
| 1000002156.81                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-counters-box.js?ver=1>                                                 | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-counters-box.js?ver=1>                                                 | application/javascript   | netdna-ssl.com       |
| 1000002156.82                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/bootstrap.transition.js?ver=3.3.6>                                         | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/bootstrap.transition.js?ver=3.3.6>                                         | application/javascript   | netdna-ssl.com       |
| 1000002156.83                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/bootstrap.tab.js?ver=3.1.1>                                                | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/bootstrap.tab.js?ver=3.1.1>                                                | application/javascript   | netdna-ssl.com       |
| 1000002156.84                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-tabs.js?ver=1>                                                         | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-tabs.js?ver=1>                                                         | application/javascript   | netdna-ssl.com       |
| 1000002156.85                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-recent-posts.js?ver=1>                                                 | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-recent-posts.js?ver=1>                                                 | application/javascript   | netdna-ssl.com       |
| 1000002156.86                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/library/Chart.js?ver=2.7.1>                                                           | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/library/Chart.js?ver=2.7.1>                                                           | application/javascript   | netdna-ssl.com       |
| 1000002156.87                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-chart.js?ver=1>                                                        | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-chart.js?ver=1>                                                        | application/javascript   | netdna-ssl.com       |
| 1000002156.88                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-flip-boxes.js?ver=1>                                                   | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-flip-boxes.js?ver=1>                                                   | application/javascript   | netdna-ssl.com       |
| 1000002156.89                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-syntax-highlighter.js?ver=1>                                           | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-syntax-highlighter.js?ver=1>                                           | application/javascript   | netdna-ssl.com       |
| 1000002156.9                     | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/wp-downloadmanager/download-css.css?ver=1.68.3>                                                                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/wp-downloadmanager/download-css.css?ver=1.68.3>                                                                    | text/css                 | netdna-ssl.com       |
| 1000002156.90                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-gallery.js?ver=1>                                                      | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-gallery.js?ver=1>                                                      | application/javascript   | netdna-ssl.com       |
| 1000002156.91                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.easyPieChart.js?ver=2.1.7>                                          | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/jquery.easyPieChart.js?ver=2.1.7>                                          | application/javascript   | netdna-ssl.com       |
| 1000002156.92                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-counters-circle.js?ver=1>                                              | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-counters-circle.js?ver=1>                                              | application/javascript   | netdna-ssl.com       |
| 1000002156.93                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/library/jquery.event.move.js?ver=2.0>                                                 | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/library/jquery.event.move.js?ver=2.0>                                                 | application/javascript   | netdna-ssl.com       |
| 1000002156.94                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-image-before-after.js?ver=1.0>                                         | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-image-before-after.js?ver=1.0>                                         | application/javascript   | netdna-ssl.com       |
| 1000002156.95                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-column-bg-image.js?ver=1>                                              | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-column-bg-image.js?ver=1>                                              | application/javascript   | netdna-ssl.com       |
| 1000002156.96                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-equal-heights.js?ver=1>                                             | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/general/fusion-equal-heights.js?ver=1>                                             | application/javascript   | netdna-ssl.com       |
| 1000002156.97                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-column.js?ver=1>                                                       | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-column.js?ver=1>                                                       | application/javascript   | netdna-ssl.com       |
| 1000002156.98                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-content-boxes.js?ver=1>                                                | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/plugins/fusion-builder/assets/js/min/general/fusion-content-boxes.js?ver=1>                                                | application/javascript   | netdna-ssl.com       |
| 1000002156.99                    | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/bootstrap.collapse.js?ver=3.1.1>                                           | <https://442r58kc8ke1y38f62ssb208-wpengine.netdna-ssl.com/wp-content/themes/Avada/includes/lib/assets/min/js/library/bootstrap.collapse.js?ver=3.1.1>                                           | application/javascript   | netdna-ssl.com       |
| EE27B2CEBC4D5129AE8DD688572AED20 | <http://rstudio.org/>                                                                                                                                                                           | <https://www.rstudio.com/>                                                                                                                                                                      | text/html                | rstudio.com          |

### HTML reading

``` r
cri_read_html("https://rstudio.org", as = "parsed")
## {html_document}
## <html class="avada-html-layout-wide applicationcache geolocation history postmessage websockets localstorage sessionstorage websqldatabase webworkers hashchange audio canvas canvastext video webgl cssgradients multiplebgs opacity rgba inlinesvg hsla supports svgclippaths smil no-touchevents fontface generatedcontent textshadow cssanimations backgroundsize borderimage borderradius boxshadow flexbox cssreflections csstransforms csstransforms3d csstransitions ua-safari ua-safari-10 ua-safari-10-0 ua-safari-10-0-2 ua-desktop ua-desktop-macintosh ua-mac_os_x ua-mac_os_x-10 ua-mac_os_x-10-12 ua-mac_os_x-10-12-2 ua-webkit ua-webkit-602 ua-webkit-602-3 ua-webkit-602-3-12 js" lang="en-US" prefix="og: http://ogp.me/ns# fb: http://ogp.me/ns/fb# og: http://ogp.me/ns#" data-useragent="Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_2) AppleWebKit/602.3.12 (KHTML, like Gecko) Version/10.0.2 Safari/602.3.12">
## [1] <head>\n<meta http-equiv="X-UA-Compatible" content="IE=edge">\n<meta http-equiv="Content-Type" content="text/html ...
## [2] <body class="home page-template page-template-100-width page-template-100-width-php page page-id-2 fusion-image-h ...
```

### Full page screenshot

``` r
full_page_screenshot("https://www.cervelo.com/media/catalog/product/cache/b7aae6d4f2b2644583da2c4e434b55ef/p/5/p5_da_di2_black_teal_1_.jpg")
```

![](man/figures/README-ex4-1.png)<!-- -->

## spectr Metrics

| Lang | \# Files |  (%) | LoC |  (%) | Blank lines |  (%) | \# Lines |  (%) |
| :--- | -------: | ---: | --: | ---: | ----------: | ---: | -------: | ---: |
| R    |        6 | 0.86 | 120 | 0.86 |          23 | 0.48 |       77 | 0.66 |
| Rmd  |        1 | 0.14 |  19 | 0.14 |          25 | 0.52 |       40 | 0.34 |

## Code of Conduct

Please note that this project is released with a Contributor Code of
Conduct. By participating in this project you agree to abide by its
terms.
